Opcode

Enum Opcode 

pub enum Opcode {
Show 57 variants Add { ty: Type, saturate: bool, rnd: bool, ftz: bool, }, Sub { ty: Type, ftz: bool, }, Clz(Type), Not(Type), Vote(Type), PopC(Type), Exit, Call(CallInst), CallPrototype {}, Abs { ty: Type, ftz: bool, }, Ex2 { ty: Type, ftz: bool, }, Rem(Type), Fma { rounding: Option<FloatRoundingMode>, ty: Type, ftz: bool, }, Mad { mode: Option<MulMode>, rounding: Option<FloatRoundingMode>, ty: Type, ftz: bool, sat: bool, }, Rcp { ty: Type, ftz: bool, approx: bool, rounding: Option<FloatRoundingMode>, }, Sqrt { ty: Type, ftz: bool, approx: bool, rounding: Option<FloatRoundingMode>, }, RSqrt { ty: Type, ftz: bool, approx: bool, rounding: Option<FloatRoundingMode>, }, Sin { ty: Type, approx: bool, ftz: bool, }, Cos { ty: Type, approx: bool, ftz: bool, }, Neg { ty: Type, ftz: bool, }, Max(Type), Min(Type), Shfl(Type), Bar { thread: u32, sync: bool, }, Cvt { from: Type, to: Type, rounding: Option<Either<FloatRoundingMode, IntegerRoundingMode>>, saturate: bool, }, Cvta { to: bool, state_space: StateSpace, size: Type, }, Cp, Ret, Mov(Type), Lg2 { ty: Type, ftz: bool, }, Mul { ty: Type, mode: Option<MulMode>, rounding: Option<FloatRoundingMode>, ftz: bool, saturate: bool, }, Mul24 { ty: Type, mode: Option<MulMode>, }, Div { approx: bool, full: bool, rounding: Option<FloatRoundingMode>, ty: Type, ftz: bool, }, Shl(Type), Shr(Type), Shf { direction: ShfDirection, mode: ShfMode, }, SetpLt, SetpGt, SetpEq, Ld(Type), Ldu(Type), Tex(Type, Type), Slct { ftz: bool, dtype: Type, stype: Type, }, Atom(Type), LdMatrix { shape: Shape2, ty: Type, xnum: u32, shared: bool, }, Mma { shape: Shape3, atype: Type, btype: Type, ctype: Type, dtype: Type, }, St(Type), And(Type), Or(Type), XOr(Type), Set { cmp_op: PredicateOp, ftz: bool, dtype: Type, stype: Type, }, Setp(PredicateOp, Type), Selp(Type), Bfe(Type), Bra, Membar, IsSpaceP(StateSpace),
}

Variants



Add

Fields

ty: Type
saturate: bool
rnd: bool
ftz: bool


Sub

Fields

ty: Type
ftz: bool


Clz(Type)

Count leading zeros



Not(Type)



Vote(Type)

Vote across thread group, Deprecated



PopC(Type)

Population count.



Exit



Call(CallInst)



CallPrototype



Abs

Fields

ty: Type
ftz: bool


Ex2

Fields

ty: Type
ftz: bool

flush-to-zero



Rem(Type)



Fma

Fields

ty: Type
ftz: bool


Mad

Fields

ty: Type
ftz: bool
sat: bool


Rcp

Fields

ty: Type
ftz: bool
approx: bool


Sqrt

Fields

ty: Type
ftz: bool
approx: bool


RSqrt

Fields

ty: Type
ftz: bool
approx: bool


Sin

Fields

ty: Type
approx: bool
ftz: bool


Cos

Fields

ty: Type
approx: bool
ftz: bool


Neg

Fields

ty: Type
ftz: bool


Max(Type)



Min(Type)



Shfl(Type)



Bar

Fields

thread: u32
sync: bool


Cvt



Cvta

Fields

to: bool
state_space: StateSpace
size: Type


Cp



Ret



Mov(Type)



Lg2

Fields

ty: Type
ftz: bool


Mul

Fields

ty: Type
ftz: bool
saturate: bool


Mul24

Fields

ty: Type


Div

Fields

approx: bool
full: bool
ty: Type
ftz: bool


Shl(Type)



Shr(Type)



Shf

Fields

direction: ShfDirection
mode: ShfMode


SetpLt



SetpGt



SetpEq



Ld(Type)



Ldu(Type)



Tex(Type, Type)



Slct

Select one source operand, based on the sign of the third operand.

Fields

ftz: bool
dtype: Type
stype: Type


Atom(Type)

Atomic reduction operations for thread-to-thread communication.



LdMatrix

Fields

shape: Shape2
ty: Type
xnum: u32
shared: bool


Mma

Fields

shape: Shape3
atype: Type
btype: Type
ctype: Type
dtype: Type


St(Type)



And(Type)



Or(Type)



XOr(Type)



Set

Fields

ftz: bool
dtype: Type
stype: Type


Setp(PredicateOp, Type)



Selp(Type)



Bfe(Type)



Bra



Membar



IsSpaceP(StateSpace)

Query whether a generic address falls within a specified state space window